(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     64047,       2409]*)
(*NotebookOutlinePosition[     64764,       2434]*)
(*  CellTagsIndexPosition[     64720,       2430]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Archetypes Workbook", "Subtitle"],

Cell[CellGroupData[{

Cell["Revision History", "Subsection"],

Cell["Alt-5 for subsection headings", "Text"],

Cell["\<\
2003/01/13   First whack
2003/01/20   Added System I
2003/01/21   Added matrices J, K
2003/03/26   Added eigensystems for square matrices
2003/03/31   Added linear transformations
2004/01/29   Changed B, moved into FCLA directory
2004/11/04   Started adding matrix reps of linear transformations\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["System A (3\[Times]3, singular, nullity1, consistent, eigenvalues)", \
"Subsection"],

Cell["\<\
A  3\[Times]3 system with non-trivial nullspace, and a degenerate eigenspace.\
\
\>", "Text"],

Cell[BoxData[{
    \(\(a = \ {{1, \(-1\), 2}, {2, 1, 1}, {1, 1, 
            0}};\)\), "\[IndentingNewLine]", 
    \(\(as = {{1, \(-1\), 2, \ 1}, {2, 1, 1, \ 8}, {1, 1, 0, \ 
            5}};\)\), "\[IndentingNewLine]", 
    \(\(ab\  = {1, 8, 5};\)\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(a // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(-1\), "2"},
            {"2", "1", "1"},
            {"1", "1", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinearSolve[a, \ ab]\)], "Input"],

Cell[BoxData[
    \({3, 2, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[as] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "1", "3"},
            {"0", "1", \(-1\), "2"},
            {"0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[a]\)], "Input"],

Cell[BoxData[
    \({{\(-1\), 1, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[RowReduce[Transpose[a]]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0"},
            {"0", "1", "0"},
            {\(-\(1\/3\)\), \(2\/3\), "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[Join[Transpose[a], IdentityMatrix[3]]]] // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "1", "0", "1", \(-1\)},
            {"0", "1", \(-1\), "0", \(-1\), "2"},
            {"0", "0", "0", "1", \(-2\), "3"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigensystem[a] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "2"},
            {\({\(-1\), 1, 1}\), \({0, 0, 0}\), \({1, 5, 3}\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["System B (3\[Times]3, nonsingular, distinct eigenvalues)", "Subsection"],

Cell[BoxData[{
    \(\(b = {{\(-7\), \(-6\), \(-12\)}, {5, 5, 7}, {1, 0, 
            4}};\)\), "\[IndentingNewLine]", 
    \(\(bs = {{\(-7\), \(-6\), \(-12\), \(-33\)}, \[IndentingNewLine]{5, 5, 
            7, 24}, \[IndentingNewLine]{1, 0, 4, 
            5}};\)\), "\[IndentingNewLine]", 
    \(\(bb\  = \ {\(-33\), 24, 5};\)\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Built from similarity transformation with unimodular matrix  and diagonal \
matrix buried under this cell.  Distinct integer eigenvalues.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(uni\  = \ {{1, 0, 0}, {1, 1, 0}, {2, 1, 1}} . {{1, 1, 1}, {0, 
            1, \(-2\)}, {0, 0, 1}}\), "\n", 
    \(Inverse[uni] . DiagonalMatrix[{\(-1\), 2, 1}] . uni\)}], "Input"],

Cell[BoxData[
    \({{1, 1, 1}, {1, 2, \(-1\)}, {2, 3, 1}}\)], "Output"],

Cell[BoxData[
    \({{\(-7\), \(-6\), \(-12\)}, {5, 5, 7}, {1, 0, 4}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-7\), \(-6\), \(-12\)},
            {"5", "5", "7"},
            {"1", "0", "4"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinearSolve[b, \ bb]\)], "Input"],

Cell[BoxData[
    \({\(-3\), 5, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[bs] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", \(-3\)},
            {"0", "1", "0", "5"},
            {"0", "0", "1", "2"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[b]\)], "Input"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[RowReduce[Transpose[b]]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0"},
            {"0", "1", "0"},
            {"0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[Join[Transpose[b], IdentityMatrix[3]]]] // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", \(-10\), \(-12\), \(-9\)},
            {"0", "1", "0", \(13\/2\), "8", \(11\/2\)},
            {"0", "0", "1", \(5\/2\), "3", \(5\/2\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigensystem[b] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1\), "1", "2"},
            {\({\(-5\), 3, 1}\), \({\(-3\), 2, 1}\), \({\(-2\), 1, 1}\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["System C (3\[Times]4, nullity 1, consistent)", "Subsection"],

Cell["3\[Times]4 system, dimension 1 null space for coefficient matrix", \
"Text"],

Cell[BoxData[{
    \(\(c = {{2, \(-3\), 1, \(-6\)}, {4, 1, 2, 9}, {3, 1, 1, 8}};\)\), "\n", 
    \(\(cb\  = \ {\(-7\), \(-7\), \(-8\)};\)\), "\n", 
    \(\(cs = {{2, \(-3\), 1, \(-6\), \(-7\)}, {4, 1, 2, 9, \(-7\)}, {3, 1, 1, 
            8, \(-8\)}};\)\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(c // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2", \(-3\), "1", \(-6\)},
            {"4", "1", "2", "9"},
            {"3", "1", "1", "8"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinearSolve[c, \ cb]\)], "Input"],

Cell[BoxData[
    \({\(-5\), 1, 6, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[cs] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "2", \(-5\)},
            {"0", "1", "0", "3", "1"},
            {"0", "0", "1", \(-1\), "6"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[c]\)], "Input"],

Cell[BoxData[
    \({{\(-2\), \(-3\), 1, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[RowReduce[Transpose[c]]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0"},
            {"0", "1", "0", "0"},
            {"0", "0", "1", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[Join[Transpose[c], IdentityMatrix[3]]]] // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "2", \(1\/7\), \(-\(4\/7\)\), "1"},
            {"0", "1", "0", "3", \(-\(2\/7\)\), \(1\/7\), "0"},
            {"0", "0", "1", \(-1\), \(-\(1\/7\)\), \(11\/7\), \(-2\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Systems D, E (3\[Times]4, nullity 2, consistent/inconsistent)", \
"Subsection"],

Cell["\<\
Identical coefficient matrix, with nullity 2.  Constant vector inside/outside \
of column space. D = E throughout, so only system of equations are analyzed \
twice.\
\>", "Text"],

Cell[BoxData[{
    \(\(d = {{2, 1, 7, \(-7\)}, {\(-3\), 4, \(-5\), \(-6\)}, {1, 1, 
            4, \(-5\)}};\)\), "\[IndentingNewLine]", 
    \(\(ds = {{2, 1, 7, \(-7\), 8}, {\(-3\), 4, \(-5\), \(-6\), \(-12\)}, {1, 
            1, 4, \(-5\), 4}};\)\), "\[IndentingNewLine]", 
    \(\(db = {8, \(-12\), 4};\)\), "\[IndentingNewLine]", 
    \(\(e = d;\)\), "\[IndentingNewLine]", 
    \(\(es\  = \ {{2, 1, 7, \(-7\), 2}, {\(-3\), 4, \(-5\), \(-6\), 3}, {1, 
            1, 4, \(-5\), 2}};\)\), "\[IndentingNewLine]", 
    \(\(eb = {2, 3, 2};\)\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(d // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2", "1", "7", \(-7\)},
            {\(-3\), "4", \(-5\), \(-6\)},
            {"1", "1", "4", \(-5\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinearSolve[d, \ db]\)], "Input"],

Cell[BoxData[
    \({4, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[ds] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "3", \(-2\), "4"},
            {"0", "1", "1", \(-3\), "0"},
            {"0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinearSolve[e, \ eb]\)], "Input"],

Cell[BoxData[
    \(LinearSolve::"nosol" \(\(:\)\(\ \)\) 
      "Linear equation encountered which has no solution."\)], "Message"],

Cell[BoxData[
    \(LinearSolve[{{2, 1, 7, \(-7\)}, {\(-3\), 4, \(-5\), \(-6\)}, {1, 1, 
          4, \(-5\)}}, {2, 3, 2}]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[es] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "3", \(-2\), "0"},
            {"0", "1", "1", \(-3\), "0"},
            {"0", "0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[d]\)], "Input"],

Cell[BoxData[
    \({{2, 3, 0, 1}, {\(-3\), \(-1\), 1, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[RowReduce[Transpose[d]]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0"},
            {"0", "1", "0", "0"},
            {\(7\/11\), \(1\/11\), "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[Join[Transpose[d], IdentityMatrix[3]]]] // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "3", \(-2\), "0", \(-\(1\/7\)\), \(4\/7\)},
            {"0", "1", "1", \(-3\), "0", \(1\/7\), \(3\/7\)},
            {"0", "0", "0", "0", "1", \(1\/7\), \(-\(11\/7\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["System F (4\[Times]4, nonsingular, eigenvalues)", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Nonsingular, unimodular construction matrix, diagonal matrix, buried under \
this cell.  One eigenvalue with multiplicity 2, other two with multiplicity \
1.\
\>", "Text"],

Cell[BoxData[{
    \(\(uni4 = {{12, \(-5\), 1, \(-1\)}, {26, \(-12\), 
            5, \(-2\)}, {39, \(-18\), 7, \(-3\)}, {\(-11\), 5, \(-2\), 
            1}};\)\), "\[IndentingNewLine]", 
    \(\(diag\  = \ 
        DiagonalMatrix[{\(-1\), 3, 2, 3}];\)\), "\[IndentingNewLine]", 
    \(Inverse[uni4] . diag . uni4\)}], "Input"]
}, Open  ]],

Cell[BoxData[{
    \(\(f = {{33, \(-16\), 10, \(-2\)}, {99, \(-47\), 
            27, \(-7\)}, {78, \(-36\), 17, \(-6\)}, {\(-9\), 2, 3, 
            4}};\)\), "\[IndentingNewLine]", 
    \(\(fb = {\(-27\), \(-77\), \(-52\), 5};\)\), "\[IndentingNewLine]", 
    \(\(fs = {{33, \(-16\), 10, \(-2\), \ \(-27\)}, {99, \(-47\), 
            27, \(-7\), \ \(-77\)}, {78, \(-36\), 
            17, \(-6\), \ \(-52\)}, {\(-9\), 2, 3, 4, \ 
            5}};\)\), "\[IndentingNewLine]", 
    \(\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(f // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"33", \(-16\), "10", \(-2\)},
            {"99", \(-47\), "27", \(-7\)},
            {"78", \(-36\), "17", \(-6\)},
            {\(-9\), "2", "3", "4"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinearSolve[f, \ fb]\)], "Input"],

Cell[BoxData[
    \({1, 2, \(-2\), 4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[fs] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "1"},
            {"0", "1", "0", "0", "2"},
            {"0", "0", "1", "0", \(-2\)},
            {"0", "0", "0", "1", "4"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[RowReduce[Transpose[f]]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0"},
            {"0", "1", "0", "0"},
            {"0", "0", "1", "0"},
            {"0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[Join[Transpose[f], IdentityMatrix[4]]]] // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", 
              "0", \(-\(86\/3\)\), \(38\/3\), \(-\(11\/3\)\), \(7\/3\)},
            {"0", "1", "0", 
              "0", \(-\(129\/2\)\), \(86\/3\), \(-\(17\/2\)\), \(31\/6\)},
            {"0", "0", "1", "0", \(-13\), "6", \(-2\), "1"},
            {"0", "0", "0", 
              "1", \(-\(45\/2\)\), \(29\/3\), \(-\(5\/2\)\), \(13\/6\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigensystem[f] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1\), "2", "3", "3"},
            {\({1, 2, 0, 1}\), \({2, 5, 2, 1}\), \({1, 1, 0, 7}\), \({17, 45, 
                21, 0}\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Systems G, H (5\[Times]2, nullity 0, consistent/inconsistent)", \
"Subsection"],

Cell[BoxData[{
    \(\(g = {{2, 3}, {\(-1\), 4}, {3, 10}, {3, \(-1\)}, {6, 
            9}};\)\), "\[IndentingNewLine]", 
    \(\(gb = {6, \(-14\), \(-2\), 20, 18};\)\), "\[IndentingNewLine]", 
    \(\(gs = {{2, 3, 6}, {\(-1\), 4, \(-14\)}, {3, 10, \(-2\)}, {3, \(-1\), 
            20}, {6, 9, 18}};\)\), "\[IndentingNewLine]", 
    \(\(h = g;\)\), "\[IndentingNewLine]", 
    \(\(hb = {5, 6, 2, \(-1\), 3};\)\), "\[IndentingNewLine]", 
    \(\(hs = {{2, 3, \ 5}, {\(-1\), 4, \ 6}, {3, 10, \ 
            2}, {3, \(-1\), \(-1\)}, {6, 9, \ 3}};\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
Identical coefficient matrix, with nullity 0.  Constant vector inside/outside \
of column space. G = H throughout, so only system of equations are analyzed \
twice.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2", "3"},
            {\(-1\), "4"},
            {"3", "10"},
            {"3", \(-1\)},
            {"6", "9"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinearSolve[g, \ gb]\)], "Input"],

Cell[BoxData[
    \({6, \(-2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[gs] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "6"},
            {"0", "1", \(-2\)},
            {"0", "0", "0"},
            {"0", "0", "0"},
            {"0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinearSolve[h, hb]\)], "Input"],

Cell[BoxData[
    \(LinearSolve::"nosol" \(\(:\)\(\ \)\) 
      "Linear equation encountered which has no solution."\)], "Message"],

Cell[BoxData[
    \(LinearSolve[{{2, 3}, {\(-1\), 4}, {3, 10}, {3, \(-1\)}, {6, 9}}, {5, 6, 
        2, \(-1\), 3}]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[hs] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0"},
            {"0", "1", "0"},
            {"0", "0", "1"},
            {"0", "0", "0"},
            {"0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[g]\)], "Input"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[RowReduce[Transpose[g]]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0"},
            {"0", "1"},
            {"2", "1"},
            {"1", \(-1\)},
            {"3", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[Join[Transpose[g], IdentityMatrix[5]]]] // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0", \(3\/11\), \(1\/33\)},
            {"0", "1", "0", "0", "0", \(-\(2\/11\)\), \(1\/11\)},
            {"0", "0", "1", "0", "0", "0", \(-\(1\/3\)\)},
            {"0", "0", "0", "1", "0", "1", \(-\(1\/3\)\)},
            {"0", "0", "0", "0", "1", "1", \(-1\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["System I (4\[Times]7, nullity 4, consistent)", "Subsection"],

Cell[BoxData[{
    \(\(i = {{1, 4, 0, \(-1\), 0, 7, \(-9\)}, {2, 8, \(-1\), 3, 9, \(-13\), 
            7}, {0, 0, 2, \(-3\), \(-4\), 12, \(-8\)}, {\(-1\), \(-4\), 2, 4, 
            8, \(-31\), 37}};\)\), "\[IndentingNewLine]", 
    \(\(ib = {3, 9, 1, 4};\)\), "\[IndentingNewLine]", 
    \(\(is\  = \ {{1, 4, 0, \(-1\), 0, 7, \(-9\), 3}, {2, 8, \(-1\), 3, 
            9, \(-13\), 7, 9}, {0, 0, 2, \(-3\), \(-4\), 12, \(-8\), 
            1}, {\(-1\), \(-4\), 2, 4, 8, \(-31\), 37, 4}};\)\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(i // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "4", "0", \(-1\), "0", "7", \(-9\)},
            {"2", "8", \(-1\), "3", "9", \(-13\), "7"},
            {"0", "0", "2", \(-3\), \(-4\), "12", \(-8\)},
            {\(-1\), \(-4\), "2", "4", "8", \(-31\), "37"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinearSolve[i, \ ib]\)], "Input"],

Cell[BoxData[
    \({4, 0, 2, 1, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[is] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "4", "0", "0", "2", "1", \(-3\), "4"},
            {"0", "0", "1", "0", "1", \(-3\), "5", "2"},
            {"0", "0", "0", "1", "2", \(-6\), "6", "1"},
            {"0", "0", "0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[i]\)], "Input"],

Cell[BoxData[
    \({{3, 0, \(-5\), \(-6\), 0, 0, 1}, {\(-1\), 0, 3, 6, 0, 1, 0}, {\(-2\), 
        0, \(-1\), \(-2\), 1, 0, 0}, {\(-4\), 1, 0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[RowReduce[Transpose[i]]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0", "0", "0"},
            {"0", "0", "1", "0", "0", "0", "0"},
            {\(-\(31\/7\)\), \(12\/7\), \(13\/7\), "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[Join[Transpose[i], IdentityMatrix[4]]]] // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "4", "0", "0", "2", "1", \(-3\), 
              "0", \(14\/31\), \(10\/31\), \(-\(3\/31\)\)},
            {"0", "0", "1", "0", "1", \(-3\), "5", 
              "0", \(3\/31\), \(11\/31\), \(6\/31\)},
            {"0", "0", "0", "1", "2", \(-6\), "6", 
              "0", \(2\/31\), \(-\(3\/31\)\), \(4\/31\)},
            {"0", "0", "0", "0", "0", "0", "0", 
              "1", \(-\(12\/31\)\), \(-\(13\/31\)\), \(7\/31\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["System J (6\[Times]9, nullity 5, consistent)", "Subsection"],

Cell[BoxData[{
    \(\(j = {{1, 2, \(-2\), 9, 3, \(-5\), \(-2\), 1, 27}, {2, 4, 3, 
            4, \(-1\), 4, 10, 2, \(-23\)}, {1, 2, 1, 3, 1, 1, 5, 
            2, \(-7\)}, {2, 4, 3, 4, \(-7\), 2, 4, 0, \(-11\)}, {1, 2, 0, 5, 
            2, \(-4\), 3, 8, 13}, {\(-3\), \(-6\), \(-1\), \(-13\), 
            2, \(-5\), \(-4\), 13, 10}};\)\), "\[IndentingNewLine]", 
    \(\(jb = {\(-5\), 18, 6, 
          20, \(-4\), \(-29\)};\)\), "\[IndentingNewLine]", 
    \(\(js = {{1, 2, \(-2\), 9, 3, \(-5\), \(-2\), 1, 27, \(-5\)}, {2, 4, 3, 
            4, \(-1\), 4, 10, 2, \(-23\), 18}, {1, 2, 1, 3, 1, 1, 5, 
            2, \(-7\), 6}, {2, 4, 3, 4, \(-7\), 2, 4, 0, \(-11\), 20}, {1, 2, 
            0, 5, 2, \(-4\), 3, 8, 
            13, \(-4\)}, {\(-3\), \(-6\), \(-1\), \(-13\), 2, \(-5\), \(-4\), 
            13, 10, \(-29\)}};\)\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(j // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", \(-2\), "9", "3", \(-5\), \(-2\), "1", "27"},
            {"2", "4", "3", "4", \(-1\), "4", "10", "2", \(-23\)},
            {"1", "2", "1", "3", "1", "1", "5", "2", \(-7\)},
            {"2", "4", "3", "4", \(-7\), "2", "4", "0", \(-11\)},
            {"1", "2", "0", "5", "2", \(-4\), "3", "8", "13"},
            {\(-3\), \(-6\), \(-1\), \(-13\), "2", \(-5\), \(-4\), "13", 
              "10"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LinearSolve[j, jb]\)], "Input"],

Cell[BoxData[
    \({6, 0, \(-1\), 0, \(-1\), 2, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[js] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "0", "5", "0", "0", "1", \(-2\), "3", "6"},
            {"0", "0", "1", \(-2\), "0", "0", "3", "5", \(-6\), \(-1\)},
            {"0", "0", "0", "0", "1", "0", "1", "1", \(-1\), \(-1\)},
            {"0", "0", "0", "0", "0", "1", "0", \(-2\), \(-3\), "2"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[j]\)], "Input"],

Cell[BoxData[
    \({{\(-3\), 0, 6, 0, 1, 3, 0, 0, 1}, {2, 0, \(-5\), 0, \(-1\), 2, 0, 1, 
        0}, {\(-1\), 0, \(-3\), 0, \(-1\), 0, 1, 0, 0}, {\(-5\), 0, 2, 1, 0, 
        0, 0, 0, 0}, {\(-2\), 1, 0, 0, 0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[RowReduce[Transpose[j]]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "1", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "1", "0", "0", "0", "0", "0"},
            {\(-1\), \(-\(11\/2\)\), "10", \(3\/2\), "0", "0", "0", "0", 
              "0"},
            {\(-\(29\/7\)\), \(-\(94\/7\)\), "22", "3", "0", "0", "0", "0", 
              "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[Join[Transpose[j], IdentityMatrix[6]]]] // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "0", "5", "0", "0", "1", \(-2\), "3", "0", 
              "0", \(-\(30\/131\)\), \(-\(4\/131\)\), \(43\/131\), \
\(-\(42\/131\)\)},
            {"0", "0", "1", \(-2\), "0", "0", "3", "5", \(-6\), "0", 
              "0", \(107\/131\), \(23\/131\), \(-\(18\/131\)\), \(45\/131\)},
            {"0", "0", "0", "0", "1", "0", "1", "1", \(-1\), "0", 
              "0", \(41\/131\), \(-\(12\/131\)\), \(-\(2\/131\)\), \
\(5\/131\)},
            {"0", "0", "0", "0", "0", "1", "0", \(-2\), \(-3\), "0", 
              "0", \(13\/131\), \(-\(7\/131\)\), \(-\(23\/131\)\), \
\(-\(8\/131\)\)},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "1", 
              "0", \(186\/131\), \(51\/131\), \(-\(188\/131\)\), \
\(77\/131\)},
            {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
              "1", \(-\(272\/131\)\), \(-\(45\/131\)\), \(58\/131\), \
\(-\(14\/131\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Matrix K (5\[Times]5, nonsingular, 3 distinct eigenvalues)", \
"Subsection"],

Cell[CellGroupData[{

Cell["Built from unimodular and diagonal matrices buried below", "Text"],

Cell[BoxData[{
    \(\(uni5\  = \ {\[IndentingNewLine]{1, 0, 0, 0, 
              0}, \[IndentingNewLine]{\(-2\), 1, 0, 0, 
              0}, \[IndentingNewLine]{2, 3, 1, 0, 0}, \[IndentingNewLine]{1, 
              0, 1, 1, 0}, \[IndentingNewLine]{\(-1\), 1, 2, 3, 
              1}} . \[IndentingNewLine]{{1, 1, 1, 
              1, \(-1\)}, \[IndentingNewLine]{0, 1, 1, 0, 
              1}, \[IndentingNewLine]{0, 0, 1, 
              2, \(-1\)}, \[IndentingNewLine]{0, 0, 0, 1, \(-2\)}, {0, 0, 0, 
              0, 1}};\)\), "\[IndentingNewLine]", 
    \(\(diag = DiagonalMatrix[{1, 1, 4, \(-2\), \(-2\)}];\)\)}], "Input"]
}, Open  ]],

Cell[BoxData[
    \(\(k = {{10, 18, 24, 24, \(-12\)}, {12, \(-2\), \(-6\), 
            0, \(-18\)}, {\(-30\), \(-21\), \(-23\), \(-30\), 39}, {27, 30, 
            36, 37, \(-30\)}, {18, 24, 30, 30, \(-20\)}};\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(b\)], "Input"],

Cell[BoxData[
    \({{\(-7\), \(-6\), \(-12\)}, {5, 5, 7}, {1, 0, 4}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(k // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"10", "18", "24", "24", \(-12\)},
            {"12", \(-2\), \(-6\), "0", \(-18\)},
            {\(-30\), \(-21\), \(-23\), \(-30\), "39"},
            {"27", "30", "36", "37", \(-30\)},
            {"18", "24", "30", "30", \(-20\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[k]\)], "Input"],

Cell[BoxData[
    \(16\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[k]\)], "Input"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[RowReduce[Transpose[k]]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[Join[Transpose[k], IdentityMatrix[5]]]] // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0", "1", \(-\(9\/4\)\), \(-\(3\/2\)\), 
              "3", \(-6\)},
            {"0", "1", "0", "0", "0", \(21\/2\), \(43\/4\), \(21\/2\), 
              "9", \(-9\)},
            {"0", "0", "1", "0", 
              "0", \(-15\), \(-\(21\/2\)\), \(-11\), \(-15\), \(39\/2\)},
            {"0", "0", "0", "1", "0", "9", \(15\/4\), \(9\/2\), 
              "10", \(-15\)},
            {"0", "0", "0", "0", "1", \(9\/2\), \(3\/4\), \(3\/2\), 
              "6", \(-\(19\/2\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigensystem[k]\)], "Input"],

Cell[BoxData[
    \({{\(-2\), \(-2\), 1, 1, 
        4}, {{2, \(-2\), 1, 0, 1}, {\(-1\), 2, \(-2\), 1, 0}, {4, \(-10\), 7, 
          0, 2}, {\(-4\), 18, \(-17\), 5, 0}, {1, \(-1\), 0, 1, 
          1}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigensystem[k] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-2\), \(-2\), "1", "1", "4"},
            {\({2, \(-2\), 1, 0, 1}\), \({\(-1\), 2, \(-2\), 1, 
                0}\), \({4, \(-10\), 7, 0, 2}\), \({\(-4\), 18, \(-17\), 5, 
                0}\), \({1, \(-1\), 0, 1, 1}\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Matrix L (5\[Times]5, singular, 2 distinct eigenvalues)", "Subsection"],

Cell[CellGroupData[{

Cell["Built from unimodular and diagonal matrices buried below", "Text"],

Cell[BoxData[{
    \(\(uni5\  = \ {\[IndentingNewLine]{1, 0, 0, 0, 
              0}, \[IndentingNewLine]{\(-2\), 1, 0, 0, 
              0}, \[IndentingNewLine]{2, 3, 1, 0, 0}, \[IndentingNewLine]{1, 
              0, 1, 1, 0}, \[IndentingNewLine]{\(-1\), 1, 2, 3, 
              1}} . \[IndentingNewLine]{{1, 1, 1, 
              1, \(-1\)}, \[IndentingNewLine]{0, 1, 1, 0, 
              1}, \[IndentingNewLine]{0, 0, 1, 
              2, \(-1\)}, \[IndentingNewLine]{0, 0, 0, 1, \(-2\)}, {0, 0, 0, 
              0, 1}};\)\), "\[IndentingNewLine]", 
    \(\(diag = DiagonalMatrix[{\(-1\), \(-1\), \(-1\), 0, 0}];\)\)}], "Input"]
}, Closed]],

Cell[BoxData[
    \(\(l = {{\(-2\), \(-1\), \(-2\), \(-4\), 
            4}, {\(-6\), \(-5\), \(-4\), \(-4\), 6}, {10, 7, 7, 
            10, \(-13\)}, {\(-7\), \(-5\), \(-6\), \(-9\), 
            10}, {\(-4\), \(-3\), \(-4\), \(-6\), 6}};\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(l // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-2\), \(-1\), \(-2\), \(-4\), "4"},
            {\(-6\), \(-5\), \(-4\), \(-4\), "6"},
            {"10", "7", "7", "10", \(-13\)},
            {\(-7\), \(-5\), \(-6\), \(-9\), "10"},
            {\(-4\), \(-3\), \(-4\), \(-6\), "6"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[l]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[l]\)], "Input"],

Cell[BoxData[
    \({{2, \(-2\), 1, 0, 1}, {\(-1\), 2, \(-2\), 1, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[RowReduce[Transpose[l]]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {\(9\/4\), \(5\/4\), \(1\/2\), "0", "0"},
            {\(5\/2\), \(3\/2\), "1", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[Join[Transpose[l], IdentityMatrix[5]]]] // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "1", \(-2\), "0", "0", \(-2\), \(-7\), "7"},
            {"0", "1", "0", \(-2\), "2", "0", "0", "4", "12", \(-11\)},
            {"0", "0", "1", "2", \(-1\), "0", "0", \(-1\), \(-2\), "1"},
            {"0", "0", "0", "0", "0", "1", "0", \(-2\), \(-6\), "5"},
            {"0", "0", "0", "0", "0", "0", "1", "4", "10", \(-9\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigensystem[l]\)], "Input"],

Cell[BoxData[
    \({{\(-1\), \(-1\), \(-1\), 0, 
        0}, {{\(-5\), 9, 0, 0, 1}, {6, \(-10\), 0, 1, 0}, {2, \(-4\), 1, 0, 
          0}, {2, \(-2\), 1, 0, 1}, {\(-1\), 2, \(-2\), 1, 0}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigensystem[l] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1\), \(-1\), \(-1\), "0", "0"},
            {\({\(-5\), 9, 0, 0, 1}\), \({6, \(-10\), 0, 1, 
                0}\), \({2, \(-4\), 1, 0, 0}\), \({2, \(-2\), 1, 0, 
                1}\), \({\(-1\), 2, \(-2\), 1, 0}\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Transformation M (5\[Rule]3, not onto)\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = {{1, 2, 3, 4, 4}, {3, 1, 4, \(-3\), 7}, {1, \(-1\), 0, \(-5\), 
          1}}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({{1, 2, 3, 4, 4}, {3, 1, 4, \(-3\), 7}, {1, \(-1\), 0, \(-5\), 
        1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(m // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "3", "4", "4"},
            {"3", "1", "4", \(-3\), "7"},
            {"1", \(-1\), "0", \(-5\), "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[m] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "1", \(-2\), "2"},
            {"0", "1", "1", "3", "1"},
            {"0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[m]\)], "Input"],

Cell[BoxData[
    \({{\(-2\), \(-1\), 0, 0, 1}, {2, \(-3\), 0, 1, 0}, {\(-1\), \(-1\), 1, 
        0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[m]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", \(-\(4\/5\)\)},
            {"0", "1", \(3\/5\)},
            {"0", "0", "0"},
            {"0", "0", "0"},
            {"0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Transformation N (5\[Rule]3, onto)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(n = {{2, 1, 3, \(-4\), 5}, {1, \(-2\), 3, \(-9\), 3}, {3, 0, 4, \(-6\), 
          5}}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({{2, 1, 3, \(-4\), 5}, {1, \(-2\), 3, \(-9\), 3}, {3, 0, 4, \(-6\), 
        5}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(n // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2", "1", "3", \(-4\), "5"},
            {"1", \(-2\), "3", \(-9\), "3"},
            {"3", "0", "4", \(-6\), "5"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[n] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "2", \(-1\)},
            {"0", "1", "0", "1", "1"},
            {"0", "0", "1", \(-3\), "2"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[n]\)], "Input"],

Cell[BoxData[
    \({{1, \(-1\), \(-2\), 0, 1}, {\(-2\), \(-1\), 3, 1, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[n]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0"},
            {"0", "1", "0"},
            {"0", "0", "1"},
            {"0", "0", "0"},
            {"0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Transformation O (3\[Rule]5, not 1-1)\
\>", "Subsection"],

Cell[BoxData[
    \(\(o = {{\(-1\), 1, \(-3\)}, {\(-1\), 2, \(-4\)}, {1, 1, 1}, {2, 3, 
            1}, {1, 0, 2}};\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(o // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1\), "1", \(-3\)},
            {\(-1\), "2", \(-4\)},
            {"1", "1", "1"},
            {"2", "3", "1"},
            {"1", "0", "2"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[o] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "2"},
            {"0", "1", \(-1\)},
            {"0", "0", "0"},
            {"0", "0", "0"},
            {"0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[o]\)], "Input"],

Cell[BoxData[
    \({{\(-2\), 1, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[o]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", \(-3\), \(-7\), \(-2\)},
            {"0", "1", "2", "5", "1"},
            {"0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Transformation P (3\[Rule]5, 1-1)", "Subsection"],

Cell[BoxData[
    \(\(p = {{\(-1\), 1, 1}, {\(-1\), 2, 2}, {1, 1, 3}, {2, 3, 1}, {\(-2\), 
            1, 3}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(p // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1\), "1", "1"},
            {\(-1\), "2", "2"},
            {"1", "1", "3"},
            {"2", "3", "1"},
            {\(-2\), "1", "3"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[p] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0"},
            {"0", "1", "0"},
            {"0", "0", "1"},
            {"0", "0", "0"},
            {"0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[p]\)], "Input"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[p]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", \(-10\), "6"},
            {"0", "1", "0", "7", \(-3\)},
            {"0", "0", "1", \(-1\), "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Transformation Q (5\[Rule]5, not 1-1, not onto)\
\>", "Subsection"],

Cell[BoxData[
    \(\(q = {{\(-2\), 3, 3, \(-6\), 3}, {\(-16\), 9, 12, \(-28\), 
            28}, {\(-19\), 7, 14, \(-32\), 37}, {\(-21\), 9, 15, \(-35\), 
            39}, {\(-9\), 5, 7, \(-16\), 16}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(q // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-2\), "3", "3", \(-6\), "3"},
            {\(-16\), "9", "12", \(-28\), "28"},
            {\(-19\), "7", "14", \(-32\), "37"},
            {\(-21\), "9", "15", \(-35\), "39"},
            {\(-9\), "5", "7", \(-16\), "16"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[q] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", \(-1\)},
            {"0", "1", "0", "0", \(-\(4\/3\)\)},
            {"0", "0", "1", "0", \(-\(1\/3\)\)},
            {"0", "0", "0", "1", \(-1\)},
            {"0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[q]\)], "Input"],

Cell[BoxData[
    \({{3, 4, 1, 3, 3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[q]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "1"},
            {"0", "1", "0", "0", \(-1\)},
            {"0", "0", "1", "0", \(-1\)},
            {"0", "0", "0", "1", "2"},
            {"0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigensystem[q]\)], "Input"],

Cell[BoxData[
    \({{\(-1\), 0, 1, 1, 
        1}, {{0, 2, 3, 3, 1}, {3, 4, 1, 3, 3}, {5, 3, 0, 0, 2}, {\(-3\), 1, 
          0, 2, 0}, {1, \(-1\), 2, 0, 0}}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Transformation R (5\[Rule]5, invertible)\
\>", "Subsection"],

Cell[BoxData[
    \(\(r = {{\(-65\), 128, 10, \(-262\), 40}, {36, \(-73\), \(-1\), 
            151, \(-16\)}, {\(-44\), 88, 5, \(-180\), 
            24}, {34, \(-68\), \(-3\), 140, \(-18\)}, {12, \(-24\), \(-1\), 
            49, \(-5\)}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(r // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-65\), "128", "10", \(-262\), "40"},
            {"36", \(-73\), \(-1\), "151", \(-16\)},
            {\(-44\), "88", "5", \(-180\), "24"},
            {"34", \(-68\), \(-3\), "140", \(-18\)},
            {"12", \(-24\), \(-1\), "49", \(-5\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[r] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[r]\)], "Input"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[r]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigensystem[r]\)], "Input"],

Cell[BoxData[
    \({{\(-1\), \(-1\), 1, 1, 
        2}, {{\(-57\), 0, \(-18\), 14, 5}, {2, 1, 0, 0, 
          0}, {\(-10\), \(-5\), \(-6\), 0, 1}, {2, 3, 1, 1, 0}, {\(-6\), 
          3, \(-4\), 3, 1}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Inverse[r] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-47\), "92", "1", \(-181\), \(-14\)},
            {"27", \(-55\), \(7\/2\), \(221\/2\), "11"},
            {\(-32\), "64", \(-1\), \(-126\), \(-12\)},
            {"25", \(-50\), \(3\/2\), \(199\/2\), "9"},
            {"9", \(-18\), \(1\/2\), \(71\/2\), "4"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Transformation S (3\[Rule]4, not 1-1, not onto)\
\>", "Subsection"],

Cell[BoxData[
    \(\(s = {{1, \(-1\), 0}, {2, 2, 1}, {3, 1, 
            1}, {\(-2\), \(-6\), \(-2\)}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", \(-1\), "0"},
            {"2", "2", "1"},
            {"3", "1", "1"},
            {\(-2\), \(-6\), \(-2\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[s] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", \(1\/4\)},
            {"0", "1", \(1\/4\)},
            {"0", "0", "0"},
            {"0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[s]\)], "Input"],

Cell[BoxData[
    \({{\(-1\), \(-1\), 4}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[s]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "1", "2"},
            {"0", "1", "1", \(-2\)},
            {"0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Transformation T (5\[Rule]6, 1-1, not onto)\
\>", "Subsection"],

Cell[BoxData[
    \(\(t = {{\(-2\), 0, 0, 0, 0}, {1, \(-2\), 0, 0, 0}, {0, 1, \(-2\), 0, 
            0}, {0, 0, 1, \(-2\), 0}, \ {0, 0, 0, 1, \(-2\)}, \ {0, 0, 0, 0, 
            1}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(t // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-2\), "0", "0", "0", "0"},
            {"1", \(-2\), "0", "0", "0"},
            {"0", "1", \(-2\), "0", "0"},
            {"0", "0", "1", \(-2\), "0"},
            {"0", "0", "0", "1", \(-2\)},
            {"0", "0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[t] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "1"},
            {"0", "0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[t]\)], "Input"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[t]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0", \(-\(1\/32\)\)},
            {"0", "1", "0", "0", "0", \(-\(1\/16\)\)},
            {"0", "0", "1", "0", "0", \(-\(1\/8\)\)},
            {"0", "0", "0", "1", "0", \(-\(1\/4\)\)},
            {"0", "0", "0", "0", "1", \(-\(1\/2\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Transformation U (6\[Rule]4, not 1-1, onto)\
\>", "Subsection"],

Cell[BoxData[
    \(\(u = {{1, 2, 12, \(-3\), 1, 6}, {2, \(-1\), \(-1\), 1, 
            0, \(-11\)}, {1, 1, 7, 2, 1, \(-3\)}, {1, 2, 12, 0, 
            5, \(-5\)}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(u // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "12", \(-3\), "1", "6"},
            {"2", \(-1\), \(-1\), "1", "0", \(-11\)},
            {"1", "1", "7", "2", "1", \(-3\)},
            {"1", "2", "12", "0", "5", \(-5\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[u] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "2", "0", "0", \(-3\)},
            {"0", "1", "5", "0", "0", "4"},
            {"0", "0", "0", "1", "0", \(-1\)},
            {"0", "0", "0", "0", "1", \(-2\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[u]\)], "Input"],

Cell[BoxData[
    \({{3, \(-4\), 0, 1, 2, 1}, {\(-2\), \(-5\), 1, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[u]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0"},
            {"0", "1", "0", "0"},
            {"0", "0", "1", "0"},
            {"0", "0", "0", "1"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Transformation V (4\[Rule] 4, invertible)\
\>", "Subsection"],

Cell[BoxData[
    \(\(v = {{1, 1, 0, 0}, {1, 0, \(-2\), 0}, {0, 0, 0, 1}, {0, 1, 
            0, \(-1\)}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(v // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "1", "0", "0"},
            {"1", "0", \(-2\), "0"},
            {"0", "0", "0", "1"},
            {"0", "1", "0", \(-1\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[v] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0"},
            {"0", "1", "0", "0"},
            {"0", "0", "1", "0"},
            {"0", "0", "0", "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[v]\)], "Input"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[v]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0"},
            {"0", "1", "0", "0"},
            {"0", "0", "1", "0"},
            {"0", "0", "0", "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[v]\)], "Input"],

Cell[BoxData[
    \(\(-2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[Join[Transpose[v], IdentityMatrix[4]]]] // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "1", "0", \(-1\), \(-1\)},
            {"0", "1", "0", "0", "0", "0", "1", "1"},
            {"0", "0", "1", 
              "0", \(1\/2\), \(-\(1\/2\)\), \(-\(1\/2\)\), \(-\(1\/2\)\)},
            {"0", "0", "0", "1", "0", "0", "1", "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Transformation W (3\[Rule]3, invertible, 3 distinct eigenvalues)\
\>", "Subsection"],

Cell[BoxData[
    \(\(w = {{19, 6, \(-4\)}, {\(-24\), \(-7\), 4}, {36, 
            12, \(-9\)}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(w // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"19", "6", \(-4\)},
            {\(-24\), \(-7\), "4"},
            {"36", "12", \(-9\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[w] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0"},
            {"0", "1", "0"},
            {"0", "0", "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[w]\)], "Input"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[w]] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0"},
            {"0", "1", "0"},
            {"0", "0", "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[w]\)], "Input"],

Cell[BoxData[
    \(\(-3\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[Join[Transpose[w], IdentityMatrix[3]]]] // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", \(-5\), \(-2\), \(4\/3\)},
            {"0", "1", "0", "24", "9", \(-\(20\/3\)\)},
            {"0", "0", "1", "12", "4", \(-\(11\/3\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigensystem[w] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"3", \(-1\), "1"},
            {\({1, \(-2\), 1}\), \({0, 2, 3}\), \({\(-1\), 3, 0}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Transformation X (4\[Rule]4, not invertible, 3 distinct eigenvalues)\
\>", "Subsection"],

Cell[BoxData[
    \(\(x = {{\(-2\), 15, 3, 27}, {0, 10, 6, 18}, {1, \(-5\), 
            0, \(-9\)}, {\(-1\), \(-4\), \(-5\), \(-8\)}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(x // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-2\), "15", "3", "27"},
            {"0", "10", "6", "18"},
            {"1", \(-5\), "0", \(-9\)},
            {\(-1\), \(-4\), \(-5\), \(-8\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[x] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "6"},
            {"0", "1", "0", "3"},
            {"0", "0", "1", \(-2\)},
            {"0", "0", "0", "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NullSpace[x]\)], "Input"],

Cell[BoxData[
    \({{\(-6\), \(-3\), 2, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RowReduce[Transpose[x]]\)], "Input"],

Cell[BoxData[
    \({{1, 0, \(-\(1\/2\)\), 0}, {0, 1, 1\/4, 0}, {0, 0, 0, 1}, {0, 0, 0, 
        0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[x]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigensystem[x] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-2\), "1", "1", "0"},
            {\({\(-3\), \(-2\), 1, 1}\), \({\(-1\), \(-2\), 0, 
                1}\), \({\(-7\), \(-2\), 3, 0}\), \({\(-6\), \(-3\), 2, 1}\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TeXForm[x]\)], "Input"],

Cell["\<\
\\left(
\\begin{array}{llll}
 -2 & 15 & 3 & 27 \\\\
 0 & 10 & 6 & 18 \\\\
 1 & -5 & 0 & -9 \\\\
 -1 & -4 & -5 & -8
\\end{array}
\\right)\
\>", "Output"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1920}, {0, 1102}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{899, 1076},
WindowMargins->{{-5, Automatic}, {Automatic, -1}},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 39, 0, 76, "Subtitle"],

Cell[CellGroupData[{
Cell[1818, 55, 38, 0, 56, "Subsection"],
Cell[1859, 57, 45, 0, 47, "Text"],
Cell[1907, 59, 319, 8, 203, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2263, 72, 90, 1, 56, "Subsection"],
Cell[2356, 75, 103, 3, 47, "Text"],
Cell[2462, 80, 290, 6, 94, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2777, 90, 48, 1, 42, "Input"],
Cell[2828, 93, 269, 8, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3134, 106, 53, 1, 42, "Input"],
Cell[3190, 109, 43, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3270, 115, 60, 1, 42, "Input"],
Cell[3333, 118, 284, 8, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3654, 131, 45, 1, 42, "Input"],
Cell[3702, 134, 50, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3789, 140, 81, 1, 42, "Input"],
Cell[3873, 143, 281, 8, 111, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4191, 156, 113, 2, 94, "Input"],
Cell[4307, 160, 323, 8, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4667, 173, 61, 1, 42, "Input"],
Cell[4731, 176, 272, 7, 77, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5052, 189, 78, 0, 42, "Subsection"],
Cell[5133, 191, 371, 7, 146, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[5529, 202, 161, 3, 73, "Text"],

Cell[CellGroupData[{
Cell[5715, 209, 200, 3, 180, "Input"],
Cell[5918, 214, 72, 1, 70, "Output"],
Cell[5993, 217, 83, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6125, 224, 48, 1, 35, "Input"],
Cell[6176, 227, 276, 8, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6489, 240, 53, 1, 42, "Input"],
Cell[6545, 243, 48, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6630, 249, 60, 1, 42, "Input"],
Cell[6693, 252, 284, 8, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7014, 265, 45, 1, 42, "Input"],
Cell[7062, 268, 36, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7135, 274, 81, 1, 42, "Input"],
Cell[7219, 277, 266, 8, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7522, 290, 113, 2, 94, "Input"],
Cell[7638, 294, 344, 8, 125, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8019, 307, 61, 1, 42, "Input"],
Cell[8083, 310, 285, 7, 77, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8417, 323, 66, 0, 42, "Subsection"],
Cell[8486, 325, 82, 1, 47, "Text"],
Cell[8571, 328, 295, 5, 94, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[8891, 337, 48, 1, 42, "Input"],
Cell[8942, 340, 287, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9266, 353, 53, 1, 42, "Input"],
Cell[9322, 356, 51, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9410, 362, 60, 1, 42, "Input"],
Cell[9473, 365, 302, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9812, 378, 45, 1, 42, "Input"],
Cell[9860, 381, 58, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9955, 387, 81, 1, 42, "Input"],
Cell[10039, 390, 281, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10357, 403, 113, 2, 94, "Input"],
Cell[10473, 407, 378, 8, 137, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[10900, 421, 85, 1, 42, "Subsection"],
Cell[10988, 424, 188, 4, 73, "Text"],
Cell[11179, 430, 584, 10, 172, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[11788, 444, 48, 1, 42, "Input"],
Cell[11839, 447, 296, 8, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12172, 460, 53, 1, 42, "Input"],
Cell[12228, 463, 46, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12311, 469, 60, 1, 42, "Input"],
Cell[12374, 472, 302, 8, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12713, 485, 53, 1, 42, "Input"],
Cell[12769, 488, 131, 2, 60, "Message"],
Cell[12903, 492, 136, 2, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13076, 499, 60, 1, 42, "Input"],
Cell[13139, 502, 302, 8, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13478, 515, 45, 1, 42, "Input"],
Cell[13526, 518, 72, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13635, 524, 81, 1, 42, "Input"],
Cell[13719, 527, 293, 8, 111, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14049, 540, 113, 2, 94, "Input"],
Cell[14165, 544, 373, 8, 137, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[14587, 558, 69, 0, 42, "Subsection"],

Cell[CellGroupData[{
Cell[14681, 562, 181, 4, 73, "Text"],
Cell[14865, 568, 328, 6, 120, "Input"]
}, Open  ]],
Cell[15208, 577, 527, 10, 172, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[15760, 591, 48, 1, 42, "Input"],
Cell[15811, 594, 345, 9, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16193, 608, 53, 1, 42, "Input"],
Cell[16249, 611, 51, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16337, 617, 60, 1, 42, "Input"],
Cell[16400, 620, 338, 9, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16775, 634, 81, 1, 42, "Input"],
Cell[16859, 637, 315, 9, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17211, 651, 113, 2, 94, "Input"],
Cell[17327, 655, 548, 12, 159, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17912, 672, 61, 1, 42, "Input"],
Cell[17976, 675, 322, 8, 58, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[18347, 689, 85, 1, 42, "Subsection"],
Cell[18435, 692, 588, 10, 224, "Input",
  InitializationCell->True],
Cell[19026, 704, 188, 4, 73, "Text"],

Cell[CellGroupData[{
Cell[19239, 712, 48, 1, 42, "Input"],
Cell[19290, 715, 306, 10, 143, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19633, 730, 53, 1, 42, "Input"],
Cell[19689, 733, 45, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19771, 739, 60, 1, 42, "Input"],
Cell[19834, 742, 327, 10, 143, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20198, 757, 51, 1, 42, "Input"],
Cell[20252, 760, 131, 2, 60, "Message"],
Cell[20386, 764, 129, 2, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20552, 771, 60, 1, 42, "Input"],
Cell[20615, 774, 324, 10, 143, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20976, 789, 45, 1, 42, "Input"],
Cell[21024, 792, 36, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21097, 798, 81, 1, 42, "Input"],
Cell[21181, 801, 302, 10, 143, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21520, 816, 113, 2, 94, "Input"],
Cell[21636, 820, 476, 10, 195, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[22161, 836, 66, 0, 42, "Subsection"],
Cell[22230, 838, 532, 8, 146, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[22787, 850, 48, 1, 42, "Input"],
Cell[22838, 853, 409, 9, 121, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23284, 867, 53, 1, 42, "Input"],
Cell[23340, 870, 55, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23432, 876, 60, 1, 42, "Input"],
Cell[23495, 879, 404, 9, 121, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23936, 893, 45, 1, 42, "Input"],
Cell[23984, 896, 170, 2, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24191, 903, 81, 1, 42, "Input"],
Cell[24275, 906, 398, 9, 133, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24710, 920, 113, 2, 94, "Input"],
Cell[24826, 924, 621, 13, 173, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[25496, 943, 66, 0, 42, "Subsection"],
Cell[25565, 945, 874, 14, 302, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[26464, 963, 48, 1, 42, "Input"],
Cell[26515, 966, 601, 12, 165, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27153, 983, 51, 1, 42, "Input"],
Cell[27207, 986, 71, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27315, 992, 60, 1, 42, "Input"],
Cell[27378, 995, 587, 11, 165, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28002, 1011, 45, 1, 42, "Input"],
Cell[28050, 1014, 237, 3, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28324, 1022, 81, 1, 42, "Input"],
Cell[28408, 1025, 606, 13, 191, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29051, 1043, 113, 2, 94, "Input"],
Cell[29167, 1047, 1087, 22, 243, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[30303, 1075, 82, 1, 42, "Subsection"],

Cell[CellGroupData[{
Cell[30410, 1080, 72, 0, 47, "Text"],
Cell[30485, 1082, 627, 10, 302, "Input"]
}, Open  ]],
Cell[31127, 1095, 253, 4, 94, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[31405, 1103, 34, 1, 42, "Input"],
Cell[31442, 1106, 83, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31562, 1112, 48, 1, 42, "Input"],
Cell[31613, 1115, 426, 10, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32076, 1130, 39, 1, 42, "Input"],
Cell[32118, 1133, 36, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32191, 1139, 45, 1, 42, "Input"],
Cell[32239, 1142, 36, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32312, 1148, 81, 1, 42, "Input"],
Cell[32396, 1151, 374, 10, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32807, 1166, 113, 2, 68, "Input"],
Cell[32923, 1170, 689, 15, 188, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33649, 1190, 47, 1, 42, "Input"],
Cell[33699, 1193, 217, 4, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33953, 1202, 61, 1, 42, "Input"],
Cell[34017, 1205, 415, 9, 58, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34481, 1220, 77, 0, 56, "Subsection"],

Cell[CellGroupData[{
Cell[34583, 1224, 72, 0, 47, "Text"],
Cell[34658, 1226, 632, 10, 453, "Input"]
}, Closed]],
Cell[35305, 1239, 283, 5, 61, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[35613, 1248, 48, 1, 42, "Input"],
Cell[35664, 1251, 429, 10, 143, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36130, 1266, 39, 1, 42, "Input"],
Cell[36172, 1269, 35, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36244, 1275, 45, 1, 42, "Input"],
Cell[36292, 1278, 83, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36412, 1284, 81, 1, 42, "Input"],
Cell[36496, 1287, 399, 10, 169, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36932, 1302, 113, 2, 94, "Input"],
Cell[37048, 1306, 535, 10, 143, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37620, 1321, 47, 1, 42, "Input"],
Cell[37670, 1324, 204, 3, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37911, 1332, 61, 1, 42, "Input"],
Cell[37975, 1335, 411, 9, 77, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[38435, 1350, 68, 2, 42, "Subsection"],

Cell[CellGroupData[{
Cell[38528, 1356, 142, 3, 42, "Input",
  InitializationCell->True],
Cell[38673, 1361, 109, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38819, 1368, 48, 1, 42, "Input"],
Cell[38870, 1371, 305, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39212, 1384, 59, 1, 42, "Input"],
Cell[39274, 1387, 299, 8, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39610, 1400, 45, 1, 42, "Input"],
Cell[39658, 1403, 119, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39814, 1410, 70, 1, 42, "Input"],
Cell[39887, 1413, 339, 10, 150, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[40275, 1429, 56, 0, 42, "Subsection"],

Cell[CellGroupData[{
Cell[40356, 1433, 147, 3, 102, "Input",
  InitializationCell->True],
Cell[40506, 1438, 114, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40657, 1445, 48, 1, 63, "Input"],
Cell[40708, 1448, 308, 8, 120, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41053, 1461, 59, 1, 63, "Input"],
Cell[41115, 1464, 302, 8, 120, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41454, 1477, 45, 1, 63, "Input"],
Cell[41502, 1480, 88, 1, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41627, 1486, 70, 1, 63, "Input"],
Cell[41700, 1489, 324, 10, 186, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[42073, 1505, 67, 2, 42, "Subsection"],
Cell[42143, 1509, 158, 3, 102, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[42326, 1516, 48, 1, 63, "Input"],
Cell[42377, 1519, 336, 10, 214, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42750, 1534, 59, 1, 63, "Input"],
Cell[42812, 1537, 327, 10, 214, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43176, 1552, 45, 1, 63, "Input"],
Cell[43224, 1555, 50, 1, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43311, 1561, 70, 1, 63, "Input"],
Cell[43384, 1564, 305, 8, 148, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[43738, 1578, 55, 0, 42, "Subsection"],
Cell[43796, 1580, 125, 2, 102, "Input"],

Cell[CellGroupData[{
Cell[43946, 1586, 48, 1, 63, "Input"],
Cell[43997, 1589, 333, 10, 186, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44367, 1604, 59, 1, 63, "Input"],
Cell[44429, 1607, 324, 10, 186, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44790, 1622, 45, 1, 63, "Input"],
Cell[44838, 1625, 36, 1, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44911, 1631, 70, 1, 63, "Input"],
Cell[44984, 1634, 306, 8, 120, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[45339, 1648, 77, 2, 42, "Subsection"],
Cell[45419, 1652, 217, 3, 94, "Input"],

Cell[CellGroupData[{
Cell[45661, 1659, 48, 1, 42, "Input"],
Cell[45712, 1662, 418, 10, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46167, 1677, 59, 1, 42, "Input"],
Cell[46229, 1680, 400, 10, 150, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46666, 1695, 45, 1, 42, "Input"],
Cell[46714, 1698, 51, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46802, 1704, 70, 1, 42, "Input"],
Cell[46875, 1707, 380, 10, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47292, 1722, 47, 1, 42, "Input"],
Cell[47342, 1725, 173, 3, 66, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[47564, 1734, 70, 2, 42, "Subsection"],
Cell[47637, 1738, 256, 4, 94, "Input"],

Cell[CellGroupData[{
Cell[47918, 1746, 48, 1, 42, "Input"],
Cell[47969, 1749, 438, 10, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48444, 1764, 59, 1, 42, "Input"],
Cell[48506, 1767, 374, 10, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48917, 1782, 45, 1, 42, "Input"],
Cell[48965, 1785, 36, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49038, 1791, 70, 1, 42, "Input"],
Cell[49111, 1794, 374, 10, 124, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49522, 1809, 47, 1, 42, "Input"],
Cell[49572, 1812, 218, 4, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49827, 1821, 57, 1, 42, "Input"],
Cell[49887, 1824, 455, 10, 243, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[50391, 1840, 77, 2, 42, "Subsection"],
Cell[50471, 1844, 119, 2, 42, "Input"],

Cell[CellGroupData[{
Cell[50615, 1850, 48, 1, 42, "Input"],
Cell[50666, 1853, 307, 9, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51010, 1867, 59, 1, 42, "Input"],
Cell[51072, 1870, 305, 9, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51414, 1884, 45, 1, 42, "Input"],
Cell[51462, 1887, 55, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51554, 1893, 70, 1, 42, "Input"],
Cell[51627, 1896, 284, 8, 80, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[51960, 1910, 73, 2, 56, "Subsection"],
Cell[52036, 1914, 199, 3, 68, "Input"],

Cell[CellGroupData[{
Cell[52260, 1921, 48, 1, 42, "Input"],
Cell[52311, 1924, 428, 11, 146, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52776, 1940, 59, 1, 42, "Input"],
Cell[52838, 1943, 413, 11, 146, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53288, 1959, 45, 1, 42, "Input"],
Cell[53336, 1962, 36, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53409, 1968, 70, 1, 42, "Input"],
Cell[53482, 1971, 451, 10, 188, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[53982, 1987, 73, 2, 56, "Subsection"],
Cell[54058, 1991, 181, 3, 68, "Input"],

Cell[CellGroupData[{
Cell[54264, 1998, 48, 1, 42, "Input"],
Cell[54315, 2001, 376, 9, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54728, 2015, 59, 1, 42, "Input"],
Cell[54790, 2018, 364, 9, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55191, 2032, 45, 1, 42, "Input"],
Cell[55239, 2035, 89, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55365, 2041, 70, 1, 42, "Input"],
Cell[55438, 2044, 383, 11, 146, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[55870, 2061, 71, 2, 56, "Subsection"],
Cell[55944, 2065, 121, 2, 42, "Input"],

Cell[CellGroupData[{
Cell[56090, 2071, 48, 1, 42, "Input"],
Cell[56141, 2074, 412, 12, 121, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56590, 2091, 59, 1, 42, "Input"],
Cell[56652, 2094, 406, 12, 121, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57095, 2111, 45, 1, 42, "Input"],
Cell[57143, 2114, 36, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57216, 2120, 70, 1, 42, "Input"],
Cell[57289, 2123, 406, 12, 121, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57732, 2140, 39, 1, 42, "Input"],
Cell[57774, 2143, 40, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57851, 2149, 113, 2, 68, "Input"],
Cell[57967, 2153, 542, 13, 133, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[58558, 2172, 94, 2, 56, "Subsection"],
Cell[58655, 2176, 112, 2, 42, "Input"],

Cell[CellGroupData[{
Cell[58792, 2182, 48, 1, 42, "Input"],
Cell[58843, 2185, 373, 11, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59253, 2201, 59, 1, 42, "Input"],
Cell[59315, 2204, 357, 11, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59709, 2220, 45, 1, 42, "Input"],
Cell[59757, 2223, 36, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59830, 2229, 70, 1, 42, "Input"],
Cell[59903, 2232, 357, 11, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60297, 2248, 39, 1, 42, "Input"],
Cell[60339, 2251, 40, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60416, 2257, 113, 2, 68, "Input"],
Cell[60532, 2261, 437, 11, 137, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61006, 2277, 61, 1, 42, "Input"],
Cell[61070, 2280, 371, 10, 77, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[61490, 2296, 98, 2, 56, "Subsection"],
Cell[61591, 2300, 150, 2, 42, "Input"],

Cell[CellGroupData[{
Cell[61766, 2306, 48, 1, 42, "Input"],
Cell[61817, 2309, 431, 12, 121, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62285, 2326, 59, 1, 42, "Input"],
Cell[62347, 2329, 409, 12, 121, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62793, 2346, 45, 1, 42, "Input"],
Cell[62841, 2349, 58, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62936, 2355, 56, 1, 42, "Input"],
Cell[62995, 2358, 114, 2, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63146, 2365, 39, 1, 42, "Input"],
Cell[63188, 2368, 35, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[63260, 2374, 61, 1, 42, "Input"],
Cell[63324, 2377, 450, 11, 77, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63823, 2394, 43, 1, 42, "Input"],
Cell[63869, 2397, 162, 9, 213, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

